/*
  ----- Knopfeigenschaften -----
*/

// Zahl der Löcher
num_holes = 4;

// Lochdurchmesser
dia_holes = 1.5;

// Knopfdurchmesser
dia_button = 14;

// Knopfdicke
height_button = 2;

// Rundlichkeit des Knopf
roundness = 2; // zwischen 1 (eckig) und 12 (rund)

// Außenkantenrundung in %
edginess = 60; // zwischen 0 und 100
// 0 = harte Kante; 100 = runde Kante


/*
  ----- Knopf -----

© CC-BY-SA 4.0; Creative Commons Lizenz 4.0
Programmiert von schmo-fu@feinfug.org
für einen OpenSCAD-Kurs bei Chaos inKL. e.V.
*/
color("green") 
difference() {
    // Knopf ...
    edge = (height_button/2 - 0.01) * edginess / 100; 
    soften_edge(edge) 
        cylinder(
            h = height_button - edge * 2, 
            d = dia_button,
            $fn = num_holes * roundness);

    // minus Vertiefung
    translate( [0,0,height_button * 2/3] )
        cylinder(
            h = height_button / 2, 
            d1 = dia_button * 0.66, 
            d2 = dia_button * 0.83,
            $fn = num_holes * roundness
        );

    // minus Knopflöcher
    translate([0,0,-1])
        make_ring_of(dia_holes*1.3, num_holes) 
            cylinder(
                h = height_button+2, 
                d = dia_holes, 
                $fn = 24);
}


/* 
   Hilfroutinen 
*/
module make_ring_of(radius, count)
{
    for (a = [0 : count - 1]) {
        angle = a * 360 / count;
        translate(radius * [sin(angle), -cos(angle), 0])
            rotate([0, 0, angle])
                children();
    }
}


module soften_edge (radius) 
{
    translate([0,0,radius])
    minkowski() {
        children();
        sphere(r=radius, $fn=24);
    }
}

